==> qtjambi-xmlpatterns-debuginfo-macos-5.15.17.jar: sources/QtJambiXmlPatterns/QXmlNamePool_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXmlPatterns/qxmlnamepool.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiXmlPatterns/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlNamePool(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlNamePool")
    QXmlNamePool *_ptr = reinterpret_cast<QXmlNamePool *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlNamePool()
void __qt_construct_QXmlNamePool_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNamePool()")
    Q_UNUSED(__java_arguments)
    QXmlNamePool *__qt_this = new(__qtjambi_ptr) QXmlNamePool();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QXmlNamePool(QXmlNamePool)
void __qt_construct_QXmlNamePool_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNamePool(QXmlNamePool)")
    jobject other0 = __java_arguments[0].l;
    const QXmlNamePool& __qt_other0 = qtjambi_cast<const QXmlNamePool& >(__jni_env, other0);
    QXmlNamePool *__qt_this = new(__qtjambi_ptr) QXmlNamePool(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QXmlNamePool
void __qt_destruct_QXmlNamePool(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlNamePool")
    reinterpret_cast<QXmlNamePool*>(ptr)->~QXmlNamePool();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlNamePool::QXmlNamePool()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_initialize_1native__Lio_qt_xmlpatterns_QXmlNamePool_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNamePool::QXmlNamePool()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNamePool_0, sizeof(QXmlNamePool), typeid(QXmlNamePool), false, &deleter_QXmlNamePool, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamePool::QXmlNamePool(QXmlNamePool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_initialize_1native__Lio_qt_xmlpatterns_QXmlNamePool_2Lio_qt_xmlpatterns_QXmlNamePool_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNamePool::QXmlNamePool(QXmlNamePool)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNamePool_1, sizeof(QXmlNamePool), typeid(QXmlNamePool), false, &deleter_QXmlNamePool, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamePool::operator=(QXmlNamePool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_assign_1native_1cref_1QXmlNamePool__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamePool *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamePool>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamePool::operator=(QXmlNamePool)", __qt_this)
        const QXmlNamePool& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlNamePool>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamePool::operator==(QXmlNamePool,QXmlNamePool)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_operator_1equal_1native_1cref_1QXmlNamePool__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QXmlNamePool *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamePool>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamePool::operator==(QXmlNamePool,QXmlNamePool)", __qt_this)
        const QXmlNamePool& __qt_arg21 = QtJambiAPI::valueReferenceFromNativeId<QXmlNamePool>(arg21);
        __java_return_value = (*__qt_this) == __qt_arg21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlNamePool *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamePool>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlNamePool *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamePool>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlNamePool(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlNamePool>("QXmlNamePool", "io/qt/xmlpatterns/QXmlNamePool");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QXmlNamePool, {
        ConstructorInfo(&__qt_construct_QXmlNamePool_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlNamePool_1, "Lio/qt/xmlpatterns/QXmlNamePool;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlNamePool);
    registerMetaType<QXmlNamePool>("QXmlNamePool");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xmlpatterns-debuginfo-macos-5.15.18.jar: sources/QtJambiXmlPatterns/QXmlNamePool_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXmlPatterns/qxmlnamepool.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiXmlPatterns/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlNamePool(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlNamePool")
    QXmlNamePool *_ptr = reinterpret_cast<QXmlNamePool *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlNamePool()
void __qt_construct_QXmlNamePool_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNamePool()")
    Q_UNUSED(__java_arguments)
    QXmlNamePool *__qt_this = new(__qtjambi_ptr) QXmlNamePool();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QXmlNamePool(QXmlNamePool)
void __qt_construct_QXmlNamePool_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNamePool(QXmlNamePool)")
    jobject other0 = __java_arguments[0].l;
    const QXmlNamePool& __qt_other0 = qtjambi_cast<const QXmlNamePool& >(__jni_env, other0);
    QXmlNamePool *__qt_this = new(__qtjambi_ptr) QXmlNamePool(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QXmlNamePool
void __qt_destruct_QXmlNamePool(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlNamePool")
    reinterpret_cast<QXmlNamePool*>(ptr)->~QXmlNamePool();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlNamePool::QXmlNamePool()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_initialize_1native__Lio_qt_xmlpatterns_QXmlNamePool_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNamePool::QXmlNamePool()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNamePool_0, sizeof(QXmlNamePool), typeid(QXmlNamePool), false, &deleter_QXmlNamePool, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamePool::QXmlNamePool(QXmlNamePool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_initialize_1native__Lio_qt_xmlpatterns_QXmlNamePool_2Lio_qt_xmlpatterns_QXmlNamePool_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNamePool::QXmlNamePool(QXmlNamePool)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNamePool_1, sizeof(QXmlNamePool), typeid(QXmlNamePool), false, &deleter_QXmlNamePool, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamePool::operator=(QXmlNamePool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_assign_1native_1cref_1QXmlNamePool__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamePool *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamePool>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamePool::operator=(QXmlNamePool)", __qt_this)
        const QXmlNamePool& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlNamePool>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamePool::operator==(QXmlNamePool,QXmlNamePool)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_equals_1native_1cref_1QXmlNamePool__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QXmlNamePool *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamePool>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamePool::operator==(QXmlNamePool,QXmlNamePool)", __qt_this)
        const QXmlNamePool& __qt_arg21 = QtJambiAPI::valueReferenceFromNativeId<QXmlNamePool>(arg21);
        __java_return_value = (*__qt_this) == __qt_arg21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlNamePool *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamePool>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNamePool_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlNamePool *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamePool>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlNamePool(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlNamePool>("QXmlNamePool", "io/qt/xmlpatterns/QXmlNamePool");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QXmlNamePool, {
        ConstructorInfo(&__qt_construct_QXmlNamePool_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlNamePool_1, "Lio/qt/xmlpatterns/QXmlNamePool;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlNamePool);
    registerMetaType<QXmlNamePool>("QXmlNamePool");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
